Python Client Examples
======================

.. toctree::

    create-upload-dataset.rst
    create-inferenceservice.rst
    create-inferencesession.rst
    create-evaluation.rst
    create-report.rst
